@@ -126,7 +126,7 @@ module OmniAuth
     #   will be passed through and set to the appropriate values.
     #
     # @yield [Options] Yields options to block for further configuration.
-    def initialize(app, *args, &block)
+    def initialize(app, *args, &block) # rubocop:disable UnusedMethodArgument
       @app = app
       @env = nil
       @options = self.class.default_options.dup
@@ -140,13 +140,13 @@ module OmniAuth
       end
 
       # Make sure that all of the args have been dealt with, otherwise error out.
-      fail(ArgumentError, "Received wrong number of arguments. #{args.inspect}") unless args.empty?
+      fail(ArgumentError.new("Received wrong number of arguments. #{args.inspect}")) unless args.empty?
 
       yield options if block_given?
     end
 
     def inspect
-      "#<#{self.class.to_s}>"
+      "#<#{self.class}>"
     end
 
     # Direct access to the OmniAuth logger, automatically prefixed
@@ -256,7 +256,7 @@ module OmniAuth
     # This is called in lieu of the normal request process
     # in the event that OmniAuth has been configured to be
     # in test mode.
-    def mock_call!(env)
+    def mock_call!(*)
       return mock_request_call if on_request_path?
       return mock_callback_call if on_callback_path?
       call_app!
@@ -467,7 +467,7 @@ module OmniAuth
       env['omniauth.error.strategy'] = self
 
       if exception
-        log :error, "Authentication failure! #{message_key}: #{exception.class.to_s}, #{exception.message}"
+        log :error, "Authentication failure! #{message_key}: #{exception.class}, #{exception.message}"
       else
         log :error, "Authentication failure! #{message_key} encountered."
       end
